#
# spec file for package libretro-picodrive
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libretro-picodrive
Version:        0~git20200816
Release:        1.6
Summary:        PicoDrive libretro core for MegaDrive/Genesis emulation
License:        NonFree
URL:            http://www.retroarch.com
Source:         %{name}-%{version}.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  make

%description
This is yet another Megadrive / Genesis / Sega CD / Mega CD / 32X / SMS
emulator, which was written having ARM-based handheld devices in mind
(such as smartphones and handheld consoles like GP2X and Pandora),
but also runs on non-ARM little-endian hardware too. This package is for
RetroArch/Libretro front-end.

%prep
%setup -q

%build
make -f Makefile.libretro

%install
mkdir -p %{buildroot}%{_libdir}/libretro
cp picodrive_libretro.so %{buildroot}%{_libdir}/libretro

%files
%dir %{_libdir}/libretro
%{_libdir}/libretro/picodrive_libretro.so

%changelog
* Wed Sep  2 2020 i@guoyunhe.me
- Update to version 0~git20200816:
  * Fix non-MSVC builds
  * Fixed MSVC compilation, VFS
* Sun Aug  9 2020 i@guoyunhe.me
- Update to version 0~git20200716:
  * libretro, build fixes ffor android/ios
  * libretro, tentative fix for android build
  * sh2 drc, optimize standard division insns (default off, needs more scrutiny)
  * Buildfix
  * Buildfix
  * Fix more conflicting types for prototypes
  * Prevent collission with PS2 SDK
  * Make sure function prototype signatures match, and put typedefs into separate header file
  * core, keep offsets header from being build if no preprocessed asm files
  * libretro, build fixes
  * libretro, build fixes
  * core, fix type issues by using stdint types
  * libretro, build fixes
  * sh2, fix for interpreter crash if drc is compiled in too
  * sh2 drc, fix for x86_64 backend
  * libretro, more fixes and cleanups for windows and osx
  * libretro, fix for windows and osx
  * libretro, changes to allow for both standalone and libretro build
  * SDL UI, 2x overlay mode, for improved color resolution
  * libretro make fix for non-arm architectures
  * sh2 drc, fix for SH2 T handling in Mips/RiscV
  * SDL UI, preparation for 2x mode, for improved color resolution
  * sh2 drc, optimisation for SH2 16x16 multiplication
  * SDL UI, fix for CD LED display
  * sh2 drc, backend 32/64 bit compatibility fixes for Mips/RiscV
  * vdp fifo, DMA bugfix
  * sh2 drc, add powerpc64le backend
  * sh2 drc, preparations for powerpc support
  * vdp rendering, bugfix for overlapping high prio sprites
  * release 1.96
  * add copyright stuff to substantially changed files
  * sh2 drc: revised ARM A32 backend optimizer
  * 32x: libretro bugfix
  * sh2: optimisations in drc
  * audio: fix for save/load
  * sh2: bugfix in drc
  * audio: SN76496 fixes
  * 32x poll detection fix
  * vdp fifo, bugfix
  * audio: add option to switch off SSG-EG
  * audio: fixes and optimizations for SSG-EG
  * audio: improve cycle accuracy of SN76496+YM2612
  * 32x, small improvement for poll detection
  * sh2, optimizations to innermost run loop
  * add sh2 ubc area to poll detection
  * 32x pwm, tiny optimization
  * sh2 timer optimization
  * menu background fix for pal mode
  * ym2612 ARM optimisations
  * vdp rendering, sprite caching optimization
  * ym2612 ARM, bug fixing and small optimizations
  * vdp DMA optimizations
  * fix for gp2x audio regression
  * vdp fifo speed optimization
  * fix for 68K cycle accounting
  * vdp rendering fixes
  * vdp rendering, fix for CD (sprites from WORD RAM)
  * ARM asm, symbol visibility fix
  * vdp rendering fixes (debug register, vscroll) for overdrive 2
  * vdp fifo speed optimization
  * hvcounter table resolution reduced
  * vdp rendering improvements
  * vdp rendering, tiny improvement
  * 32x, small improvement for poll detector
  * vdp, some small improvements
  * fix config file parsing for long filenames
  * arm asm sprite rendering: add line accidently deleted in ea431e9
  * ARM SVP drc revived
  * vdp sprite rendering fixes
  * more ARM asm sprite rendering bugfixes
  * improved hi prio sprite rendering speed
  * vdp, tentative fix for save/load compatibility
  * fix for VINT while DMA is running
  * fix for EI insn in cz80 (partial revert of 43e1401)
  * bugfix for ARM asm sprite rendering
  * vdp fifo, refined timing
  * vdp sprite rendering fix
  * vdp fifo, another revision
  * vdp sprite handling improvement (SAT cache)
  * vdp fifo, tentative fix for broken save/load
  * vdp rendering fixes
  * 32X poll detection fix
  * fix compatibility with ancient gas
  * vdp fifo: kludge for DMA fill interrupted by CPU
  * sh2 drc: fix for crash in generated code on x86_64
  * revised VDP fifo implementation
  * new hvcounter tables as per spritesmind.net threads
  * regression fix for gp2x 8bit fast mode
  * improved VRAM128K support (overdrive 2)
  * VDP timing improvements
  * added debug reg sprite plane support (fixes some issues in overdrive 2 demo)
  * sprite rendering improvements for masking and limit edge cases
  * audio fixes for overdrive demo
  * emulator timing fixes, VDP DMA fixes, improved DAC audio
  * bug fixes in drc, audio, display
  * audio: added SSG-EG to YM2612, plus some timing changes for SN76496+YM2612
  * add DC filter to sound mixer to remove potential PCM DC offset
  * sh2 drc: updates from mame for ym2612 sound
  * sh2 drc: optimize T bit handling for A64
  * sh2 drc: fix speed regression
  * sh2 drc: cleanup, fix for drc crash, for mips code emitter
  * remove textrels with -fPIC/-fPIE (for android/ios)
  * sh2 drc, tentative MIPS32/64 Release 2 support
  * release 1.95
  * sh2 drc: bug fixing
  * sh2 drc: fixed some RISC-V bugs
  * sh2 drc, small improvements and bug fixes for code emitters
  * sh2 drc, improved memory management
  * sh2 drc: RISC-V (RV64IM) code emitter, some work on MIPS64
  * sh2 drc: RISC-V (RV64IM) code emitter, some work on MIPS64
  * sh2 drc: optimizations for MIPS code emitting
  * sh2 drc: moved host register assignment to code emitters, minor bugfixing
  * 32x, finetuning
  * fix gp2x regression
  * sh2 drc: reorganised block mgmt code, plus some small scale optimisations
  * sh2 drc: bugfix in block management
  * sh2 drc: bugfix in block management
  * sh2 drc bugfix for aarch64/mips
  * 32x, improved auto frame skip, plus new config option for max auto skip
  * 32x, configurable pwm irq optimization to reduce pwm irq load
  * 32x, speed improvement
  * sh2 drc: speed optimization and bugfixing
  * sh2 drc: fix i386 regression
  * sh2 drc: bug fixing and optimization in register cache and branch handling
  * sh2 drc: drc exit, block linking and branch handling revised (overlooked commit)
  * sh2 drc: drc exit, block linking and branch handling revised
  * sh2 drc: improved RTS call stack cache
  * sh2 drc: rework of register cache to implement basic loop optmization
  * various smallish optimizations, cleanups, and bug fixes
  * cleanup and microoptimizations in SH2 hw handling
  * some drawing code C optimisations
  * bug fix in comm poll fifo, and back to -O3
  * pff... README, 2nd try
  * configuration changes and README
  * cleanup config files, copyright stuff
  * fix for mkoffsets without multiarch binutils
  * various small fixes and optimsations
  * sh2 drc: add aarch64 backend for A64
  * sh2 drc: add mipsel backend for MIPS32 Release 1 (for JZ47xx)
  * SH2 drc: register cache overhaul (bugfixing, speed, readability)
  * SH2 drc: bug fixing and small speed improvements
  * 32X: memory access and polling bug fixes
  * sh2 drc, x86 code emitter: use x86-64 registers R8-R15
  * 32x DMA memory copy performance optimisation
  * sh2 drc, change utils abi to pass sh2 PC in arg0 (reduces compiled code size)
  * sh2 drc, keep T bit in host flags as long as possible
  * add xSR/RTS call stack cache to sh2 drc
  * polling detection: communication poll fifo to avoid comm data loss
  * sh2 memory access improvements, revive ARM asm memory functions
  * sh2 drc, register cache optimisations
  * sh2 drc, block management bugfixes and cleanup
  * sh2 drc, add detection for in-memory polling
  * sh2 drc, add loop detector, handle delay/idle loops
  * sh2 drc, code emitter cleanup, add ARM reorder stage to reduce interlock
  * sh2 drc, make B/W read functions signed (reduces generated code size)
  * sh2 drc, improved constant handling and register allocator
  * speed improvement and fixes for 32x ARM asm draw
  * add literal pool to sh2 drc (for armv[456] without MOVT/W)
  * sh2 drc, reuse blocks if already previously compiled (speedup for Virtua *)
  * various small improvements and fixes
  * overhaul of translation cache and sh2 literals handling
  * added branch cache to sh2 drc to improve cross-tcache jump speed
  * sh2 memory interface optimzations
  * overhaul of the register cache (improves generated code by some 10+%%)
  * debug stuff, bug fixing
  * move saving SH2 SR into memory access and do so only if needed
  * add 32bit memory access functions for SH2
  * sh2 drc: sh2 addr modes generalization, more const propagation, code gen optimizations
  * DRC: reworked scan_block (fix register usage masks, better block and literals detection)
  * minor changes
  * reworked palette and buffer handling due to some 32X bugs
  * revamped 32X draw arm asm code
  * kludges for wwf raw, nfl
  * substituted tool to obtain target structure offsets (for asm)
  * improved sh2 clock handling, bug fixing + small improvement to drc emitters
  * sh2 drc host disassembler integration for gp2x
  * bugfix for 32x
  * bfd-less arm disassembler for gph
  * config for x86 (32 bit only, for SH2 drc), add/revive profiling
  * arm asm memory access functions for m/s68k
  * config templates for gp2x, caanoo, dingux either with system toolchain (open2x,gph,opendingux) or ubuntu arm(gcc 4.7 is highest possible),mips
  * arm asm syntax fixes for open2x
  * make gp2x mp3 playback functional (need to unpack and compile helix decoder separately in platform/common/helix)
  * fix gp2x compilation (using linaro arm gcc 4.7 on ubuntu)
  * release 1.93
  * libretro: Allow setting GIT_VERSION.
  * Makefile: Build with optimizations if DEBUG=0
  * Remove not longer files in Picodrive for PS2
  * Change GSKit PS2 version
  * Update picodrive
  * Define HAVE_NO_LANGEXTRA
  * Adapt to newlib
  * Add option to change sound quality
  * Copy tile-based fast renderer buffer
  * Add option to change renderer
* Mon Feb 10 2020 Guo Yunhe <i@guoyunhe.me>
- Initial version
